@@ -8,6 +8,8 @@ pub mod alert_request;
 pub use self::alert_request::AlertRequest;
 pub mod ansible_extra_vars;
 pub use self::ansible_extra_vars::AnsibleExtraVars;
+pub mod ansible_extra_vars_request;
+pub use self::ansible_extra_vars_request::AnsibleExtraVarsRequest;
 pub mod ansible_state_enum;
 pub use self::ansible_state_enum::AnsibleStateEnum;
 pub mod artifact_types_enum;
@@ -42,18 +44,12 @@ pub mod device_calibration_request;
 pub use self::device_calibration_request::DeviceCalibrationRequest;
 pub mod device_config;
 pub use self::device_config::DeviceConfig;
-pub mod device_config_request;
-pub use self::device_config_request::DeviceConfigRequest;
 pub mod device_key_pair;
 pub use self::device_key_pair::DeviceKeyPair;
-pub mod device_public_key;
-pub use self::device_public_key::DevicePublicKey;
 pub mod device_request;
 pub use self::device_request::DeviceRequest;
 pub mod device_state;
 pub use self::device_state::DeviceState;
-pub mod device_state_request;
-pub use self::device_state_request::DeviceStateRequest;
 pub mod email_auth_request;
 pub use self::email_auth_request::EmailAuthRequest;
 pub mod error_detail;
@@ -68,6 +64,10 @@ pub mod experiment_device_config;
 pub use self::experiment_device_config::ExperimentDeviceConfig;
 pub mod gcode_file;
 pub use self::gcode_file::GcodeFile;
+pub mod license;
+pub use self::license::License;
+pub mod license_request;
+pub use self::license_request::LicenseRequest;
 pub mod mobile_auth_request;
 pub use self::mobile_auth_request::MobileAuthRequest;
 pub mod model_artifact;
@@ -140,8 +140,6 @@ pub mod paginated_device_config_list;
 pub use self::paginated_device_config_list::PaginatedDeviceConfigList;
 pub mod paginated_device_list;
 pub use self::paginated_device_list::PaginatedDeviceList;
-pub mod paginated_device_public_key_list;
-pub use self::paginated_device_public_key_list::PaginatedDevicePublicKeyList;
 pub mod paginated_device_state_list;
 pub use self::paginated_device_state_list::PaginatedDeviceStateList;
 pub mod paginated_experiment_device_config_list;
@@ -150,6 +148,8 @@ pub mod paginated_experiment_list;
 pub use self::paginated_experiment_list::PaginatedExperimentList;
 pub mod paginated_gcode_file_list;
 pub use self::paginated_gcode_file_list::PaginatedGcodeFileList;
+pub mod paginated_license_list;
+pub use self::paginated_license_list::PaginatedLicenseList;
 pub mod paginated_model_artifact_list;
 pub use self::paginated_model_artifact_list::PaginatedModelArtifactList;
 pub mod paginated_octo_print_device_list;
@@ -238,6 +238,8 @@ pub mod release;
 pub use self::release::Release;
 pub mod release_channel_enum;
 pub use self::release_channel_enum::ReleaseChannelEnum;
+pub mod release_request;
+pub use self::release_request::ReleaseRequest;
 pub mod remote_command_event;
 pub use self::remote_command_event::RemoteCommandEvent;
 pub mod remote_command_event_event_type_enum;
